@@ -16,7 +16,7 @@ use Term::ReadKey;
 use Term::ReadLine;
 use YAML;
 
-our $VERSION = '1.7'; # VERSION
+our $VERSION = '1.8'; # VERSION
 
 # Capture ARGV at Load
 my @ORIG_ARGS;
@@ -46,24 +46,21 @@ our %EXPORT_TAGS = (
     output => \@output_tags,
 );
 
-my $ARGV_AT_INIT    = 1;
+my $ARGV_AT_INIT    = 0;
 my $COPY_ARGV       = 0;
 our $_init_complete = 0;
 
 sub import {
     my (@args) = @_;
 
-    my $explicit_argv = 0;
     my @import = ();
     # We need to process the config options
     foreach my $arg ( @args ) {
         if( $arg eq 'delay_argv' ) {
             $ARGV_AT_INIT = 0;
-            $explicit_argv = 1;
         }
         elsif( $arg eq 'preprocess_argv' ) {
             $ARGV_AT_INIT = 1;
-            $explicit_argv = 1;
         }
         elsif( $arg eq 'copy_argv' ) {
             $COPY_ARGV = 1;
@@ -73,10 +70,6 @@ sub import {
             push @import, $arg;
         }
     }
-    if( !$explicit_argv ) {
-        my ($package) = caller();
-        $ARGV_AT_INIT = $package eq 'main';
-    }
 
     CLI::Helpers->export_to_level( 1, @import );
 }
@@ -101,17 +94,17 @@ sub import {
             color!
             verbose|v+
             debug
-            debug-class:s
+            debug-class=s
             quiet
-            data-file:s
+            data-file=s
             syslog!
-            syslog-facility:s
-            syslog-tag:s
+            syslog-facility=s
+            syslog-tag=s
             syslog-debug!
-            tags:s
+            tags=s
             nopaste
             nopaste-public
-            nopaste-service:s
+            nopaste-service=s
         );
 
         my $argv;
@@ -616,7 +609,7 @@ CLI::Helpers - Subroutines for making simple command line scripts
 
 =head1 VERSION
 
-version 1.7
+version 1.8
 
 =head1 SYNOPSIS
 
@@ -882,17 +875,15 @@ Instead of messing with C<@ARGV>, operate on a copy of C<@ARGV>.
 =item B<preprocess_argv>
 
 This causes the C<@ARGV> processing to happen during the C<INIT> phase, after
-import but before runtime. This is the default when being imported from the
-C<main> package. This is usually OK for scripts, but for use in libraries, it may
-be undesirable.
+import but before runtime. This is usually OK for scripts, but for use in
+libraries, it may be undesirable.
 
     use CLI::Helpers qw( :output preprocess_argv );
 
 =item B<delay_argv>
 
 This causes the C<@ARGV> processing to happen when the first call to a function
-needing it run, usually an C<output()> call. This is the default anytime
-L<CLI::Helpers> is imported from namespace that isn't C<main>.
+needing it run, usually an C<output()> call. This is the default.
 
     use CLI::Helpers qw( :output delay_argv );
 
@@ -1042,7 +1033,7 @@ Brad Lhotsky <brad@divisionbyzero.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2019 by Brad Lhotsky.
+This software is Copyright (c) 2020 by Brad Lhotsky.
 
 This is free software, licensed under:
 
@@ -1068,7 +1059,7 @@ Mohammad S Anwar <mohammad.anwar@yahoo.com>
 
 =back
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
